pub struct HeaderBody(/* private fields */);Implementations
Sourceimpl HeaderBody
impl HeaderBody
Sourcepub fn to_cbor_bytes(&self) -> Vec<u8> ⓘ
pub fn to_cbor_bytes(&self) -> Vec<u8> ⓘ
- Serialize this type to CBOR bytes
- This type type supports encoding preservation so this will preserve round-trip CBOR formats.
- If created from scratch the CBOR will be canonical.
Sourcepub fn to_canonical_cbor_bytes(&self) -> Vec<u8> ⓘ
pub fn to_canonical_cbor_bytes(&self) -> Vec<u8> ⓘ
- Serialize this type to CBOR bytes using canonical CBOR encodings
Sourcepub fn from_cbor_bytes(cbor_bytes: &[u8]) -> Result<HeaderBody, JsError>
pub fn from_cbor_bytes(cbor_bytes: &[u8]) -> Result<HeaderBody, JsError>
- Create this type from CBOR bytes
Sourcepub fn to_cbor_hex(&self) -> String
pub fn to_cbor_hex(&self) -> String
- Serialize this type to CBOR bytes encoded as a hex string (useful for working with CIP30).
- This type type supports encoding preservation so this will preserve round-trip CBOR formats.
- If created from scratch the CBOR will be canonical.
Sourcepub fn to_canonical_cbor_hex(&self) -> String
pub fn to_canonical_cbor_hex(&self) -> String
- Serialize this type to CBOR bytes using canonical CBOR encodings as hex bytes
Sourcepub fn from_cbor_hex(cbor_bytes: &str) -> Result<HeaderBody, JsError>
pub fn from_cbor_hex(cbor_bytes: &str) -> Result<HeaderBody, JsError>
- Create this type from the CBOR bytes encoded as a hex string.
- This is useful for interfacing with CIP30
Sourceimpl HeaderBody
impl HeaderBody
Sourceimpl HeaderBody
impl HeaderBody
pub fn block_number(&self) -> u64
pub fn slot(&self) -> u64
pub fn prev_hash(&self) -> Option<BlockHeaderHash>
pub fn issuer_vkey(&self) -> Vkey
pub fn vrf_vkey(&self) -> VRFVkey
pub fn vrf_result(&self) -> VRFCert
pub fn block_body_size(&self) -> u64
pub fn block_body_hash(&self) -> BlockBodyHash
pub fn operational_cert(&self) -> OperationalCert
pub fn protocol_version(&self) -> ProtocolVersion
pub fn new( block_number: u64, slot: u64, prev_hash: Option<BlockHeaderHash>, issuer_vkey: &Vkey, vrf_vkey: &VRFVkey, vrf_result: &VRFCert, block_body_size: u64, block_body_hash: &BlockBodyHash, operational_cert: &OperationalCert, protocol_version: &ProtocolVersion, ) -> Self