pub struct OperationalCert(/* private fields */);Implementations
Sourceimpl OperationalCert
impl OperationalCert
Sourcepub fn to_cbor_bytes(&self) -> Vec<u8> ⓘ
pub fn to_cbor_bytes(&self) -> Vec<u8> ⓘ
- Serialize this type to CBOR bytes
- This type type supports encoding preservation so this will preserve round-trip CBOR formats.
- If created from scratch the CBOR will be canonical.
Sourcepub fn to_canonical_cbor_bytes(&self) -> Vec<u8> ⓘ
pub fn to_canonical_cbor_bytes(&self) -> Vec<u8> ⓘ
- Serialize this type to CBOR bytes using canonical CBOR encodings
Sourcepub fn from_cbor_bytes(cbor_bytes: &[u8]) -> Result<OperationalCert, JsError>
pub fn from_cbor_bytes(cbor_bytes: &[u8]) -> Result<OperationalCert, JsError>
- Create this type from CBOR bytes
Sourcepub fn to_cbor_hex(&self) -> String
pub fn to_cbor_hex(&self) -> String
- Serialize this type to CBOR bytes encoded as a hex string (useful for working with CIP30).
- This type type supports encoding preservation so this will preserve round-trip CBOR formats.
- If created from scratch the CBOR will be canonical.
Sourcepub fn to_canonical_cbor_hex(&self) -> String
pub fn to_canonical_cbor_hex(&self) -> String
- Serialize this type to CBOR bytes using canonical CBOR encodings as hex bytes
Sourcepub fn from_cbor_hex(cbor_bytes: &str) -> Result<OperationalCert, JsError>
pub fn from_cbor_hex(cbor_bytes: &str) -> Result<OperationalCert, JsError>
- Create this type from the CBOR bytes encoded as a hex string.
- This is useful for interfacing with CIP30
Sourceimpl OperationalCert
impl OperationalCert
pub fn hot_vkey(&self) -> KESVkey
pub fn sequence_number(&self) -> u64
pub fn kes_period(&self) -> u64
pub fn sigma(&self) -> Ed25519Signature
pub fn new( hot_vkey: &KESVkey, sequence_number: u64, kes_period: u64, sigma: &Ed25519Signature, ) -> Self